@@ -10,10 +10,10 @@ http://self-issued.info/docs/draft-jones-json-web-token-01.html
 
 
 __title__ = 'pyjwt'
-__version__ = '1.4.1'
+__version__ = '1.6.4'
 __author__ = 'José Padilla'
 __license__ = 'MIT'
-__copyright__ = 'Copyright 2015 José Padilla'
+__copyright__ = 'Copyright 2015-2018 José Padilla'
 
 
 from .api_jwt import (
@@ -22,8 +22,10 @@ from .api_jwt import (
 )
 from .api_jws import PyJWS
 from .exceptions import (
-    InvalidTokenError, DecodeError, InvalidAudienceError,
-    ExpiredSignatureError, ImmatureSignatureError, InvalidIssuedAtError,
-    InvalidIssuerError, ExpiredSignature, InvalidAudience, InvalidIssuer,
-    MissingRequiredClaimError
+    InvalidTokenError, DecodeError, InvalidAlgorithmError,
+    InvalidAudienceError, ExpiredSignatureError, ImmatureSignatureError,
+    InvalidIssuedAtError, InvalidIssuerError, ExpiredSignature,
+    InvalidAudience, InvalidIssuer, MissingRequiredClaimError,
+    InvalidSignatureError,
+    PyJWTError,
 )
